pub struct ElementBinding {
pub path: String,
pub strength: BindingStrength,
pub value_set_url: String,
pub description: Option<String>,
}Expand description
Element binding to a ValueSet
This structure is shared between the validator and code generator. Generated resources embed these as static constants for elements with required bindings.
Fields
path: StringElement path (e.g., “Patient.gender”)
strength: BindingStrengthBinding strength
value_set_url: StringValueSet canonical URL
description: Option<String>Human-readable description
Implementations